@@ -1,12 +1,16 @@
 package Import::Base;
 # ABSTRACT: Import a set of modules into the calling module
-$Import::Base::VERSION = '0.014';
+$Import::Base::VERSION = '1.000';
 use strict;
 use warnings;
 use mro ();
 use Import::Into;
 use Module::Runtime qw( use_module );
 
+require Exporter;
+
+our @ISA = qw(Exporter);
+
 sub modules {
     my ( $class, $bundles, $args ) = @_;
     my @modules = ();
@@ -167,6 +171,12 @@ sub _import_modules {
             $module =~ s/^-//;
         }
 
+        if ($module->isa("Import::Base")) {
+            $module->export_to_level( 2, $module, @{ $imports } );
+
+            next;
+        }
+
         use_module( $module );
         if ( defined $version ) {
             $module->$method( { level => 2, version => $version }, @{ $imports } );
@@ -189,7 +199,7 @@ Import::Base - Import a set of modules into the calling module
 
 =head1 VERSION
 
-version 0.014
+version 1.000
 
 =head1 SYNOPSIS
 
@@ -560,6 +570,32 @@ Using the above boilerplate will ensure that you start with all the basic functi
 One advantage the dynamic API has is the ability to remove modules from superclasses, or
 completely control the order that modules are imported, even from superclasses.
 
+=head2 Exporting symbols from the base class
+
+Import::Base inherits from Exporter and allows for EXPORT_OK usage.
+
+    package My::Base;
+    use base 'Import::Base';
+
+    our @EXPORT_OK = qw($joy);
+
+    our @IMPORT_MODULES = (
+        'strict',
+        'warnings',
+        feature => [qw( :5.10 )],
+        'My::Base' => [qw( $joy )],
+    );
+
+    our $joy = "Is everywhere";
+
+    package main;
+
+    use My::Base;
+
+    say $joy;
+
+Notice how the base class 'My::Base' is in it's own IMPORT_MODULES definition.
+
 =head1 METHODS
 
 =head2 modules( $bundles, $args )
@@ -689,6 +725,28 @@ Having to track down another project to figure out what modules are active in
 the current package is a lot of work, creating frustration for contributing
 authors.
 
+=head1 KNOWN ISSUES
+
+=over 4
+
+=item Moo::Role does not work if base module shares the same file as role package
+
+When trying to import L<Moo::Role> using Import::Base, the role will not
+be applied if it shares the same file as the Import::Base module. For
+safety and sanity, you should keep your Import::Base module separate
+from classes and roles.
+
+=item Dancer plugins do not work when applied with Import::Base
+
+Dancer plugins check, at compile time, to see if they can be imported into
+the consuming class by looking for the Dancer DSL. Because Import::Base uses
+Module::Runtime to load the class, Dancer::Plugin thinks Module::Runtime is
+the calling class, sees there is no DSL to register itself with, and bails.
+
+See L<https://github.com/PerlDancer/Dancer2/pull/1136> for more information.
+
+=back
+
 =head1 SEE ALSO
 
 =over
@@ -698,6 +756,12 @@ authors.
 The module that provides the functionality to create this module. If Import::Base
 doesn't do what you want, look at Import::Into to build your own.
 
+=item L<Importer|Importer>
+
+This module wraps the C<import> method of other modules, allowing you to rename
+the symbols you import. If you need to change a name, use this module together
+with Import::Base.
+
 =item L<perl5|perl5>
 
 This module is very similar, and has a bunch of built-in bundles and features for
@@ -707,8 +771,7 @@ your own module bundles.
 =item L<ToolSet|ToolSet>
 
 ToolSet is very similar. Its API just uses package methods instead of package
-variables. It also allows for exporting symbols directly from the bundle,
-something Import::Base does not yet allow (patches welcome).
+variables. It also allows for exporting symbols directly from the bundle.
 
 =item L<sanity|sanity>
 
@@ -729,6 +792,12 @@ This one also requires configuration files in a home directory, so is not shippa
 
 Doug Bell <preaction@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Brian Medley
+
+Brian Medley <pub-github@bmedley.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Doug Bell.
